﻿using System.Globalization;
using Microsoft.AspNetCore.Components;
using ReportingServices.Shared.HelperClasses;
using ReportingServices.Shared.Models.PlanningReport;

namespace ReportingServices.Client.Pages;

public partial class WeeklyPartChangesReport
{

    [Parameter] public string? EndDate { get; set; }
    [Parameter] public string? StartDate { get; set; }

    [Inject] protected HttpClient? HttpClient { get; set; }
    [Inject] protected NavigationManager? NavigationManager { get; set; }
    [Inject] protected ILogger<WeeklyPartChangesReport>? Logger { get; set; }

    protected WeeklyPartChanges? _weeklyPartChanges;

    protected override async Task OnInitializedAsync()
    {
        if (Logger is null)
            throw new NullReferenceException(nameof(Logger));
        if (HttpClient is null)
            throw new NullReferenceException(nameof(HttpClient));
        if (NavigationManager is null)
            throw new NullReferenceException(nameof(NavigationManager));

        string datetimeFormat = "yyyy-MM-dd HH:mm:ss";
        DateTime endDate = EndDate is null ? DateTime.Now : DateTime.ParseExact(EndDate, datetimeFormat, CultureInfo.InvariantCulture);
        DateTime startDate = StartDate is null ? endDate.AddDays(-3) : DateTime.ParseExact(StartDate, datetimeFormat, CultureInfo.InvariantCulture);

        string partChangeUrl = "https://localhost:7196/api/" + "ScrapeDB/" + "PartChanges?startDate=" + startDate.ToString() + "&endDate=" + endDate.ToString();
        string psnwoRunsUrl = "https://localhost:7196/api/" + "ScrapeDB/" + "PSNWO?startDate=" + startDate.ToString() + "&endDate=" + endDate.ToString();

        Logger.LogInformation("Part Change URL: {url}", partChangeUrl);
        Logger.LogInformation("PSN WO Runs URL: {url}", psnwoRunsUrl);

        _weeklyPartChanges = new();

        try
        {
            int numberOfPartChanges = await ApiCaller.GetApi<int>(partChangeUrl);
            List<ReactorPSNWORuns> reactorPSNWORuns = await ApiCaller.GetApi<List<ReactorPSNWORuns>>(psnwoRunsUrl);

            _weeklyPartChanges.TotalPartChanges = numberOfPartChanges;
            _weeklyPartChanges.StartDate = startDate.ToShortDateString();
            _weeklyPartChanges.EndDate = endDate.ToShortDateString();
            _weeklyPartChanges.ReactorPSNWORuns = reactorPSNWORuns;
        }
        catch (Exception ex)
        {
            Logger.LogCritical(ex, "Failed to get a response from API calls.");
            NavigationManager.NavigateTo("Error");
        }
    }
}